// Biblioteka pomocu koje cemo dohvatiti podatke sa servera
import axios from "axios";

// URL sa kojeg cemo dohvatiti podatke
// Ovaj URL vraca podatke o jednom todo-u
const url = "https://jsonplaceholder.typicode.com/todos/1";

// Interfejs koji opisuje strukturu todo objekta
interface Todo {
	userId: number;
	id: number;
	title: string;
	completed: boolean;
}

// Funkcija koja prikazuje podatke o todo-u
// Ovo je arrow funkcija, sto znaci da se koristi sintaksa (parametri) => { telo funkcije }
const logTodo = (todo: Todo) => {
	// Destrukturiranje objekta
	const { userId, id, title, completed } = todo;
	console.log(`
	ID korisnika: ${userId}
	ID: ${id}
	Naslov: ${title}
	Zavrsen? ${completed}
`);
};

// Funkcija koja dohvata podatke sa servera
// Ovo je async funkcija, sto znaci da koristi asinhrono programiranje
// Ovo je korisno kada zelimo da izvrsimo neki zadatak koji traje duze vreme
// Na primer, dohvat podataka sa servera
const fetchTodo = async () => {
	// Koristimo try-catch blok kako bismo uhvatili eventualne greske
	try {
		// Saljemo GET zahtev serveru pomocu axios biblioteke i cekamo odgovor
		const response = await axios.get<Todo>(url);
		// Iz odgovora izvlacimo podatke o todo-u
		const todo = response.data;
		// Pozivamo funkciju koja prikazuje podatke o todo-u
		logTodo(todo);
	} catch (error) {
		// Ukoliko se desi greska, ispisujemo je u terminalu
		console.error("Greska:", error);
	}
};

// Najzad, pozivamo funkciju koja dohvata podatke sa servera
fetchTodo();
