// Definisanje interfejsa
interface Osoba {
	ime: string;
	godine: number;
	pozdrav(): string; // Metoda koja vraća string
}

// Korišćenje interfejsa
const osoba: Osoba = {
	ime: "Marko",
	godine: 30,
	pozdrav(): string {
		return `Zdravo, moje ime je ${this.ime}`;
	},
};

console.log(osoba.pozdrav()); // Zdravo, moje ime je Marko

// Tipovi (type) se mogu koristiti na sličan način kao interfejsi
type Automobil = {
	marka: string;
	model: string;
	godina: number;
	vozi(): void; // Metoda koja ne vraća vrednost (void)
};

// Korišćenje tipa
const automobil: Automobil = {
	marka: "Toyota",
	model: "Corolla",
	godina: 2020,
	vozi(): void {
		console.log("Vozim se!");
	},
};

automobil.vozi(); // Vozim se!

// Primer interfejsa za argumente funkcije
interface Knjiga {
	naslov: string;
	autor: string;
	godinaIzdanja: number;
}

// Kreiranje objekta koji implementira interfejs
const knjiga: Knjiga = {
	naslov: "Na Drini ćuprija",
	autor: "Ivo Andrić",
	godinaIzdanja: 1945,
};

// Funkcija koja koristi interfejs kao argument
const ispisKnjige = (knjiga: Knjiga) => {
	// Destruktruiranje objekta
	const { naslov, autor, godinaIzdanja } = knjiga;
	console.log(`Naslov: ${naslov}`);
	console.log(`Autor: ${autor}`);
	console.log(`Godina izdanja: ${godinaIzdanja}`);
};

// Pozivanje funkcije sa objektom koji implementira interfejs
ispisKnjige(knjiga);
