// Primitivni tipovi
// TypeScript automatski prepoznaje tip, pa nije potrebno eksplicitno ga navoditi

const broj = 5; // number tip
const tekst = "Zdravo, svete!"; // string tip
const tacno = true; // boolean tip
const nista = null; // null tip
const nedefinisano = undefined; // undefined tip

// Razlika između let i const
// const se koristi za promenljive koje ne menjaju vrednost
// let se koristi za promenljive koje mogu menjati vrednost

let promenljivBroj = 10;
promenljivBroj = 20; // promenljivBroj može menjati vrednost

const konstantanBroj = 30;
// konstantaBroj = 40; Ovo je greska, jer konstantanBroj ne može menjati vrednost

console.log(promenljivBroj); // 20
console.log(konstantanBroj); // 30

// Razlika između undefined i null
// undefined predstavlja promenljivu koja nije inicijalizovana
// null predstavlja namerno odsustvo vrednosti

// Koristi se let, jer nismo sigurni da li će promenljiva biti inicijalizovana
let neinicijalizovanaPromenljiva;
console.log(neinicijalizovanaPromenljiva); // undefined

const namernoPraznaPromenljiva = null;
console.log(namernoPraznaPromenljiva); // null

const osoba1 = {
	ime: "Marko",
	godine: 30,
}; // TypeScript automatski prepoznaje tip
console.log(osoba1);

// Objekti
const osoba2: { ime: string; godine: number } = {
	ime: "Ana",
	godine: 25,
}; // objekat sa svojstvima ime i godine
console.log(osoba2);

// Kada eksplicitno navoditi tip?

// 1) Funkcija koja vraća tip any
const koordinateJSON = '{"x": 10, "y": 20}';
const koordinate: { x: number; y: number } = JSON.parse(koordinateJSON);
console.log(koordinate); // {x: 10, y: 20}

// 2) Kada deklarisemo promenljivu na jednoj liniji
// i inicijalizujemo je kasnije
const reci = ["crvena", "zelena", "plava"];
let pronadjenaRec: boolean;

pronadjenaRec = false;
for (let i = 0; i < reci.length; i++) {
	if (reci[i] === "zelena") {
		pronadjenaRec = true;
	}
}

console.log(pronadjenaRec); // true

// 3) Promenljiva čiji tip ne može biti pravilno izveden
const datumi: (string | Date)[] = [];
datumi.push("2030-10-01");
datumi.push(new Date());

datumi.forEach((datum) => {
	console.log(datum);
});
