import { FunctionComponent } from "react";
import maleAvatar from "./images/male-avatar.png";
import femaleAvatar from "./images/female-avatar.png";

// Interface koji definiše tipove za props objekat komponente UserCard
interface UserCardProps {
	isMale: boolean;
	name: string;
	description: string;
	profileUrl: string;
}

// Komponenta UserCard koja prikazuje karticu korisnika
// Argumenti su potrebni podaci o korisniku (pol, profilna slika, ime, opis, URL profila)
// Koristimo destrukturisanje kako bismo iz props objekta izvukli potrebne vrednosti
const UserCard: FunctionComponent<UserCardProps> = ({
	isMale,
	name,
	description,
	profileUrl,
}) => {
	// U zavisnosti od pola korisnika, prikazujemo odgovarajuću profilnu sliku
	const imageSrc = isMale ? maleAvatar : femaleAvatar;

	return (
		// Umesto class atributa koristimo className
		// Stilizovanje se vrši pomoću Bootstrap klasa
		<div className="col-xl-4">
			<div className="card mb-5" style={{ width: "400px" }}>
				<img
					className="card-img-top"
					src={imageSrc}
					alt="User Avatar"
					style={{ width: "100%" }}
				/>
				<div className="card-body">
					<h5 className="card-title">{name}</h5>
					<p className="card-text">{description}</p>
					<a href={profileUrl} className="btn btn-primary">
						Pogledaj profil
					</a>
				</div>
			</div>
		</div>
	);
};

export default UserCard;
